=======
History
=======

0.1.0
-----

- Migrate installation to backend settings
- Support `exists` and `neexists` lookups

0.0.1 - 0.0.2
-------------

- Support extra regex lookups
- Support negaete lookups
